@@ -1,17 +1,19 @@
 # -*- coding: utf-8 -*-
+# flake8: noqa
+# type: ignore
 
 """Command line interface for PyStow."""
 
+from __future__ import annotations
+
 import os
 from typing import Optional, Sequence
 
 import click
 
-from . import api
-
 
 @click.group()
-def main():
+def main() -> None:
     """Run the PyStow CLI."""
 
 
@@ -20,6 +22,8 @@ def main():
 @click.option("--name")
 def join(keys: Sequence[str], name: Optional[str]):
     """List a directory."""
+    from . import api
+
     click.echo(api.join(*keys, name=name))
 
 
@@ -27,6 +31,8 @@ def join(keys: Sequence[str], name: Optional[str]):
 @click.argument("keys", nargs=-1)
 def ls(keys: Sequence[str]):
     """List a directory."""
+    from . import api
+
     directory = api.join(*keys)
     _ls(directory)
 
@@ -38,6 +44,8 @@ def ls(keys: Sequence[str]):
 @click.option("--force", is_flag=True)
 def ensure(keys: Sequence[str], url: str, name: Optional[str], force: bool):
     """Ensure a file is downloaded."""
+    from . import api
+
     path = api.ensure(*keys, url=url, name=name, force=force)
     _ls(path.parent)
 
@@ -48,5 +56,16 @@ def _ls(directory):
     os.system(command)  # noqa:S605
 
 
+@main.command(name="set")
+@click.argument("module")
+@click.argument("key")
+@click.argument("value")
+def set_config(module: str, key: str, value: str):
+    """Set a configuration value."""
+    from .config_api import write_config
+
+    write_config(module, key, value)
+
+
 if __name__ == "__main__":
     main()
